@@ -1,21 +1,15 @@
 import os
 import pytest
-from urllib.parse import urlparse
 
-from firepit.asyncstorage import AsyncStorage
-from firepit.asyncstorage import SyncWrapper
+from firepit.aio import get_async_storage
+from firepit.aio.asyncstorage import AsyncDBCache
 from firepit.exceptions import SessionNotFound
 
 
 async def async_storage(tmpdir, clear=True):
     dbname = os.getenv('FIREPITDB', str(tmpdir.join('test.db')))
     session = os.getenv('FIREPITID', 'test-session')
-    store = AsyncStorage(dbname, session)
-    url = urlparse(dbname)
-    if url.scheme == 'postgresql':
-        store = AsyncStorage(dbname, session)
-    if url.scheme in ['sqlite3', '']:
-        store = SyncWrapper(url.path, session)
+    store = get_async_storage(dbname, session)
     await store.attach()
 
     if clear:
@@ -41,4 +35,22 @@ async def test_async_basics(fake_bundle_file, tmpdir):
     assert 'http://www8.example.com/page/176' in urls
     assert 'http://www27.example.com/page/64' in urls
 
+    url_table = await store.lookup('url', ['value'])
+    urls = {row['value'] for row in url_table}
+    assert 'http://www8.example.com/page/176' in urls
+    assert 'http://www27.example.com/page/64' in urls
+
+    conns = await store.lookup('network-traffic',
+                               ['src_ref.value', 'src_port', 'dst_ref.value', 'dst_port', 'protocols'])
+    assert conns[0]['src_ref.value'] == '192.168.212.97'
+
+    cache = AsyncDBCache(store)
+    metadata = await cache.get_metadata()
+    print(metadata)
+    exp = {'observed-data', 'identity', 'url', 'network-traffic', 'ipv4-addr', 'user-account'}
+    assert set(await cache.tables()) == exp
+    assert set(await cache.types()) == exp
+    assert await cache.views() == []
+    assert set(await cache.columns('url')) == {'id', 'value'}
+
     await store.delete()
